==> aiohttp-spyne-1.0.0.tar.gz: aiohttp-spyne-1.0.0/aiohttp_spyne/aio_spyne.py <==
import typing

from aiohttp import web
from spyne import Application

from .aio_base import AioBase


class AIOSpyne:
    """
    AioHttp base for spyne framework.
    """

    def __init__(self,
                 spyne_app: Application,
                 chunked: bool = False,
                 threads: typing.Optional[int] = None):
        """
        Initialize Spyne aiohttp base.

        Args:
            spyne_app: Spyne application
            chunked: Enable chunked encoding
            threads: Thread count if thread pool is wanted for execution.
                     None if no threads are wanted.
        """
        self._base = AioBase(
            spyne_app,
            chunked=chunked,
            threads=threads)

    async def post(self, request: web.Request) -> web.StreamResponse:
        """
        Accepts POST SOAP requests and handles them.
        Returns standard AioHTTP response objects.

        Args:
            request: AioHttp Request object

        Returns:
            AioHttp response object
        """
        return await self._base.handle_rpc_request(request, request.app)

    async def get(self, request: web.Request) -> web.StreamResponse:
        """
        Accepts GET SOAP requests and handles them. If path is postfixed
        with either '.wsdl' or '?WSDL', request is handled as a WSDL
        fetch request.

        Args:
            request: Request object

        Returns:
            AioHttp response object
        """
        url = str(request.url).lower()
        if url.endswith('?wsdl') or url.endswith('.wsdl'):
            return await self._base.handle_wsdl_request(request, request.app)
        return await self._base.handle_rpc_request(request, request.app)

==> aiohttp-spyne-1.1.0.tar.gz: aiohttp-spyne-1.1.0/aiohttp_spyne/aio_spyne.py <==
import typing

from aiohttp import web
from spyne import Application

from .aio_base import AioBase


class AIOSpyne:
    """
    AioHttp base for spyne framework.
    """

    def __init__(
        self,
        spyne_app: Application,
        chunked: bool = False,
        threads: typing.Optional[int] = None,
    ) -> None:
        """
        Initialize Spyne aiohttp base.

        Args:
            spyne_app: Spyne application
            chunked: Enable chunked encoding
            threads: Thread count if thread pool is wanted for execution.
                     None if no threads are wanted.
        """
        self._base = AioBase(spyne_app, chunked=chunked, threads=threads)

    async def post(self, request: web.Request) -> web.StreamResponse:
        """
        Accepts POST SOAP requests and handles them.
        Returns standard AioHTTP response objects.

        Args:
            request: AioHttp Request object

        Returns:
            AioHttp response object
        """
        return await self._base.handle_rpc_request(request, request.app)

    async def get(self, request: web.Request) -> web.StreamResponse:
        """
        Accepts GET SOAP requests and handles them. If path is postfixed
        with either '.wsdl' or '?WSDL', request is handled as a WSDL
        fetch request.

        Args:
            request: Request object

        Returns:
            AioHttp response object
        """
        url = str(request.url).lower()
        if url.endswith("?wsdl") or url.endswith(".wsdl"):
            return await self._base.handle_wsdl_request(request, request.app)
        return await self._base.handle_rpc_request(request, request.app)
